import { LitElement } from 'lit';
import { InterfaceLookType } from '@umbraco-ui/uui-base/lib/types';
export declare type ButtonState = null | 'waiting' | 'success' | 'failed';
declare const UUIButtonElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").LabelMixinInterface) & typeof LitElement;
/**
 *  @element uui-button
 *  @fires {UUIButtonEvent} click - fires when the element is clicked
 *  @slot - for button contents
 *  @description - All-round button
 *  @cssprop --uui-button-height - set the button height
 *  @cssprop --uui-button-border-width - set the border width
 *  @cssprop --uui-button-border-color - set the border color
 *  @cssprop --uui-button-border-radius - set the border radius
 *  @cssprop --uui-button-font-weight - set the font weight
 *  @cssprop --uui-button-background-color - set the background color
 *  @cssprop --uui-button-background-color-hover - set the background color for hover state
 *  @cssprop --uui-button-border-color-hover - set the border color for hover state
 *  @cssprop --uui-button-contrast - set the text color
 *  @cssprop --uui-button-contrast-hover - set the text color for hover state
 *  @cssprop --uui-button-background-color-disabled - set the background color for disabled state
 *  @cssprop --uui-button-contrast-disabled - set the text color for disabled state
 */
export declare class UUIButtonElement extends UUIButtonElement_base {
    static styles: import("lit").CSSResult[];
    /**
     * Disables the button, changes the looks of it and prevents if from emitting the click event
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    /**
     * Changes the look of the button to one of the predefined, symbolic looks. For example - set this to positive if you want nice, green "confirm" button.
     * @type {""|"primary"|"secondary"|"outline"|"placeholder"|"positive"|"warning"|"danger"}
     * @attr
     * @default ""
     */
    look: InterfaceLookType;
    /**
     * Makes the left and right padding of the button narrower.
     * @type {boolean}
     * @attr
     * @default false
     */
    compact: boolean;
    /**
     * Sets the state of the button. With waiting state a loader will show, the success state and fail states display icons. State is reset do default automatically after 3 seconds.
     * @type {null |'waiting' | 'success' | 'failed'}
     * @attr
     * @default null
     */
    state: ButtonState;
    constructor();
    private onHostClick;
    connectedCallback(): void;
    updated(changedProperties: any): void;
    private __renderState;
    render(): import("lit-html").TemplateResult<1>;
}
export {};
